---
name: Bug report
about: Create a report to help us improve
title: "🪲 [BUG] Description of problem"
labels: bug
assignees: ''

---

## Describe the bug

A clear and concise description of what the bug is or the error code you got. e.g.

```python
KeyError: 'Passing list-likes to .loc or [] with any missing labels is no longer supported, see https://pandas.pydata.org/pandas-docs/stable/user_guide/indexing.html#deprecate-loc-reindex-listlike'
```

## To Reproduce

Steps to reproduce the behavior:

1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

### Failing tests

- [ ] No applicable test failed, need to create.
- [ ]

### Triggering line of code

### Thoughts on resolution

### Full stack trace

### Environment

Operating system:
Context (conda, jupyter, etc):
Environment (e.g. output from `conda list`):
